<?php

switch ($messaggio) {

case "Inserisci i prezzi per l'anno":  		$messaggio = "Добавить прайсы для года"; break;
case "Prezzi della":  				$messaggio = "Прайсы"; break;
case "tariffa":  				$messaggio = "тариф"; break;
case "soprannominata":  			$messaggio = "назван"; break;
case "Dal":  					$messaggio = "От"; break;
case "al":  					$messaggio = "к"; break;
case "inserisci i nuovi prezzi":  		$messaggio = "добавить новые прайсы"; break;
case "modifica i prezzi già inseriti":  	$messaggio = "измените уже вставленные прайсы"; break;
case "Costi aggiuntivi":  			$messaggio = "Дополнительные расходы"; break;
case "Nome del nuovo costo aggiuntivo":		$messaggio = "Новое имя для дополнительного расхода"; break;
case "da applicare":  				$messaggio = "применить"; break;
case "sempre":  				$messaggio = "всегда"; break;
case "su richiesta":  				$messaggio = "по запросу"; break;
case "chiedi per quanto deve essere moltiplicato":	$messaggio = "спросить, на сколько это должно быть умножено"; break;
case "considera il costo finale come letto(i) aggiuntivo(i)":	$messaggio = "рассматривайте эту единичную стоимость как добавочное место(а)"; break;
case "numero di settimane":  			$messaggio = "число недель"; break;
case "numero di giorni":  			$messaggio = "число дней"; break;
case "tutte":  					$messaggio = "все"; break;
case "tutti":  					$messaggio = "все"; break;
case "tutte meno una":  			$messaggio = "все минус один"; break;
case "tutti meno uno":  			$messaggio = "все минус один"; break;
case "chiedere":  				$messaggio = "спросить"; break;
case "considera il costo settimanale come letto(i) aggiuntivo(i)":	$messaggio = "рассматривать эту еженедельную стоимость как добавочное место(а)"; break;
case "considera il costo giornaliero come letto(i) aggiuntivo(i)":	$messaggio = "рассматривать эту ежедневную стоимость как добавочное место(а)"; break;
case "della tariffa arrotondato a":  		$messaggio = "тарифа округленного до"; break;
case "considera il costo percentuale come letto(i) aggiuntivo(i)":	$messaggio = "рассматривать эту процентную стоимость как добавочное место(а)"; break;
case "Procedi nell'inserimento del nuovo costo aggiuntivo":	$messaggio = "Продолжить добавление нового дополнительного расхода"; break;
case "Caparra":  				$messaggio = "Депозит"; break;
case "arrotondata a":  				$messaggio = "округлен до"; break;
case "Inserisci o modifica la caparra":  	$messaggio = "Вставить или изменить депозит"; break;
case "Vedi i prezzi già inseriti":  		$messaggio = "Посмотреть цены уже вставленные"; break;
case "Torna al menù principale":  		$messaggio = "Назад к главному меню"; break;
case "Si deve inserire la percentuale":  	$messaggio = "Вы должны вставить процент"; break;
case "La caparra è stata modificata":  		$messaggio = "Депозит был изменен"; break;
case "Si deve specificare quando applicare il costo di fine locazione":	$messaggio = "Вы должны выбрать, как применить единичную стоимость"; break;
case "Si deve inserire il nome del costo aggiuntivo":	$messaggio = "Вы должны вставить наименование дополнительного расхода"; break;
case "Il costo aggiuntivo finale":  		$messaggio = "Единичный дополнительный расход"; break;
case "Per chiedere il numero da moltiplicare, il costo aggiuntivo finale non deve essere applicato automaticamente":	$messaggio = "Чтобы спросить на сколько это должно быть умножено, единичный дополнительный расход не должен быть применен автоматически"; break;
case "Si deve specificare quando applicare il costo settimanale":	$messaggio = "Вы должны выбрать, как применить еженедельную стоимость"; break;
case "Si deve specificare quando applicare il costo giornaliero":	$messaggio = "Вы должны выбрать, как применить ежедневную стоимость"; break;
case "e il numero di settimane":  		$messaggio = "и число недель"; break;
case "e il numero di giorni":  			$messaggio = "и число дней"; break;
case "Per chiedere il numero di settimane o il numero da moltiplicare, il costo aggiuntivo settimanale non deve essere applicato automaticamente":	$messaggio = "Чтобы спросить число недель или на сколько это должно быть умножено, еженедельные дополнительные расходы не должны быть применены автоматически"; break;
case "Per chiedere il numero di giorni o il numero da moltiplicare, il costo aggiuntivo giornaliero non deve essere applicato automaticamente":	$messaggio = "Чтобы спросить число дней или на сколько это должно быть умножено, ежедневные дополнительные расходы не должны быть применены автоматически"; break;
case "Il costo aggiuntivo settimanale":  	$messaggio = "Еженедельные дополнительные расходы "; break;
case "Il costo aggiuntivo giornaliero":  	$messaggio = "Ежедневные дополнительные расходы "; break;
case "Si deve specificare quando applicare il costo percentuale":	$messaggio = "Вы должны выбрать, как применить процентную стоимость"; break;
case "e il valore dell'arrotondamento":		$messaggio = "и значение для округления к"; break;
case "Per chiedere per quanto deve essere moltiplicato il costo aggiuntivo percentuale non deve essere applicato automaticamente":	$messaggio = "Чтобы спросить на сколько это должно быть умножено, процентные дополнительные расходы не должны быть применены автоматически"; break;
case "Il costo aggiuntivo percentuale":		$messaggio = "Процентные дополнительные расходы "; break;
case "è stato inserito":  			$messaggio = "был вставлен"; break;
case "Nessun dato è stato inserito":  		$messaggio = "Никакие данные не были вставлены"; break;
case "Il soprannome della":  			$messaggio = "Имя"; break;
case "Il soprannome":  				$messaggio = "Имя"; break;
case "Le date del periodo numero":  		$messaggio = "Даты периода номер"; break;
case "sono sbagliate":  			$messaggio = "неправильны"; break;
case "Il periodo":  				$messaggio = "Период"; break;
case "si sovrappone ad un periodo precedente":	$messaggio = "частично покрывает  другой период"; break;
case "Un prezzo nel periodo numero":  		$messaggio = "Прайс в периоде номер"; break;
case "è stato cambiato":  			$messaggio = "был изменен"; break;
case "Il prezzo del periodo":  			$messaggio = "Прайс периода"; break;
case "è stato inserito":  			$messaggio = "был вставлен"; break;
case "Il prezzo del periodo numero":  		$messaggio = "Прайс периода номер"; break;
case "è sbagliato":  				$messaggio = "неправилен"; break;
case "I soldi del costo finale sono sbagliati":	$messaggio = "Деньги для единичной стоимости неправильны"; break;
case "I soldi del costo settimanale sono sbagliati":	$messaggio = "Деньги для еженедельной стоимости неправильны"; break;
case "I soldi del costo giornaliero sono sbagliati":	$messaggio = "Деньги для ежедневной стоимости неправильны"; break;
case "I soldi del costo percentuale sono sbagliati":	$messaggio = "Деньги для процентной стоимости неправильны"; break;
case "Inserzione per settimane":  		$messaggio = "Вставка на еженедельной основе"; break;
case "Settimane dal":  				$messaggio = "Недели от"; break;
case "Dom/Lun":  				$messaggio = "Вс/Пн"; break;
case "Lun/Mar":  				$messaggio = "Пн/Вт"; break;
case "Mar/Mer":  				$messaggio = "Вт/Ср"; break;
case "Mer/Gio":  				$messaggio = "Ср/Чт"; break;
case "Gio/Ven":  				$messaggio = "Чт/Пт"; break;
case "Ven/Sab":  				$messaggio = "Пт/Сб"; break;
case "Sab/Dom":  				$messaggio = "Сб/Вс"; break;
case "inserisci o modifica i prezzi":  		$messaggio = "Вставить или изменить прайсы"; break;
case "Le date sono sbagliate":  		$messaggio = "Даты неправильны"; break;
case "Il formato dei soldi è sbagliato":  	$messaggio = "Формат денег неправилен"; break;
case "I prezzi per le settimane dal":  		$messaggio = "Прайсы для недель от"; break;
case "della <b>tariffa":  			$messaggio = " <b>тарифа"; break;
case "sono stati inseriti":  			$messaggio = "были вставлены"; break;
case "si":  					$messaggio = "да"; break;
case "no":  					$messaggio = "нет"; break;
case "assegnato automaticamente con tariffe":  	$messaggio = "автоматически назначено для тарифов"; break;
case "nessuna":  				$messaggio = "никто"; break;
case "scegliere":  				$messaggio = "выбрать"; break;
case "mostrare nella pagina di inserzione prenotazioni":	$messaggio = "показать страницу добавления брони"; break;
case "Torna indietro":  			$messaggio = "Назад"; break;
case "Continua":  				$messaggio = "Продолжить"; break;
case "Tipo di costo aggiuntivo":  		$messaggio = "Тип дополнительных расходов"; break;
case "unico":  					$messaggio = "единичный"; break;
case "settimanale":  				$messaggio = "еженедельный"; break;
case "giornaliero":  				$messaggio = "ежедневный"; break;
case "il prezzo totale":  			$messaggio = "полный прайс"; break;
case "la caparra":  				$messaggio = "депозит"; break;
case "totale meno caparra":  			$messaggio = "итог минус депозит"; break;
case "minimo":  				$messaggio = "минимум"; break;
case "massimo":  				$messaggio = "максимум"; break;
case "esattamente":  				$messaggio = "точно"; break;
case "settimane":  				$messaggio = "недели"; break;
case "giorni":  				$messaggio = "дни"; break;
case "Se possibile":  				$messaggio = "Если возможно"; break;
case "Sempre":  				$messaggio = "Всегда"; break;
case "Associare a specifiche settimane della prenotazione":	$messaggio = "Связать с определенными неделями брони"; break;
case "Associare a specifici giorni della prenotazione":	$messaggio = "Связать с определенными днями брони"; break;
case "Tutte":  					$messaggio = "Все"; break;
case "Tutti":  					$messaggio = "Все"; break;
case "Tutte meno":  				$messaggio = "Все минус"; break;
case "Tutti meno":  				$messaggio = "Все минус"; break;
case "la prima":  				$messaggio = "первый"; break;
case "il primo":  				$messaggio = "первый"; break;
case "l'ultima":  				$messaggio = "последний"; break;
case "l'ultimo":  				$messaggio = "последний"; break;
case "Chiedere":  				$messaggio = "Спросить"; break;
case "settimane sì":  				$messaggio = "недели да"; break;
case "giorni sì":  				$messaggio = "дни да"; break;
case "settimane no":  				$messaggio = "недели нет"; break;
case "giorni no":  				$messaggio = "дни нет"; break;
case "e":  					$messaggio = "и"; break;
case "Giorni della settimana selezionati":  	$messaggio = "Выбранные дни недели"; break;
case "Lunedì":  				$messaggio = "Понедельник"; break;
case "Martedì":  				$messaggio = "Вторник"; break;
case "Mercoledì":  				$messaggio = "Среду"; break;
case "Giovedì":  				$messaggio = "Четверг"; break;
case "Venerdì":  				$messaggio = "Пятница"; break;
case "Sabato":  				$messaggio = "Суббота"; break;
case "Domenica":  				$messaggio = "Воскресенье"; break;
case "Moltiplicare il costo per":  		$messaggio = "Умножить стоимость на"; break;
case "Uno":  					$messaggio = "Один"; break;
case "Chiedere":  				$messaggio = "Спросить"; break;
case "Numero di persone":  			$messaggio = "Число людей"; break;
case "Numero di persone totale":  		$messaggio = "Полное число людей"; break;
case "escluse quelle dei costi con letti aggiuntivi":	$messaggio = "исключая их из затрат с добавочными местами"; break;
case "Periodi in cui è permesso inserire il costo":	$messaggio = "Периоды, в которые можно вставить эту стоимость"; break;
case "In tutti":  				$messaggio = "Все"; break;
case "Solo nei periodi selezionati":  		$messaggio = "Только выбранные периоды"; break;
case "dal":  					$messaggio = "от"; break;
case "Elimina un periodo":  			$messaggio = "Удалить период"; break;
case "Aggiungi un periodo":  			$messaggio = "Добавить период"; break;
case "se tutte le settimane della prenotazione sono all'interno dei periodi selezionati":	$messaggio = "если все недели брони находятся в отобранных периодах"; break;
case "se tutti i giorni della prenotazione sono all'interno dei periodi selezionati":	$messaggio = "если все дни брони находятся в отобранных периодах"; break;
case "se anche una sola settimana della prenotazione è all'interno dei periodi selezionati":	$messaggio = "если даже только одна неделя брони находится в отобранных периодах"; break;
case "se anche un solo giorno della prenotazione è all'interno dei periodi selezionati":	$messaggio = "если даже только один день брони находится в отобранных периодах"; break;
case "applicare il costo solo in settimane permesse all'interno della prenotazione":	$messaggio = "применить стоимость только к разрешенным неделям в броне"; break;
case "applicare il costo solo in giorni permessi all'interno della prenotazione":	$messaggio = "примените стоимость только к разрешенным дням в броне"; break;
case "Caratteristiche del costo da mantenere quando si modifica una prenotazione":	$messaggio = "Характеристики стоимости сохранить, когда бронь изменена"; break;
case "Valore percentuale":  			$messaggio = "Процентное значение"; break;
case "e settimane associate":  			$messaggio = "и связанные недели"; break;
case "e giorni associati":  			$messaggio = "и связанные дни"; break;
case "Assegnazione settimane":  		$messaggio = "Назначение недель"; break;
case "Assegnazione giorni":  			$messaggio = "Назначение дней"; break;
case "Numero per cui viene moltiplicato":  	$messaggio = "Число, на которое это умножено"; break;
case "Periodi permessi":  			$messaggio = "Разрешенные периоды"; break;
case "Associazione alle tariffe":  		$messaggio = "Ассоциация с тарифами"; break;
case "Mostrare nella pagina di inserimento delle prenotazioni":	$messaggio = "Показать в странице добавления броней"; break;
case "Si":  					$messaggio = "Да"; break;
case "No":  					$messaggio = "Нет"; break;
case "Considerare il costo come letto/i aggiuntivo/i":	$messaggio = "Рассматривать этот дополнительный расход как дополнительное место(а)"; break;
case "Limitarne il numero che è possibile avere contemporaneamente in uno stesso periodo":	$messaggio = "Ограничить число, чтобы было возможно иметь одновременно в том же периоде"; break;
case "Valore del costo":  			$messaggio = "Значение стоимости"; break;
case "fisso di":  				$messaggio = "исправлено из"; break;
case "percentuale su":  			$messaggio = "процент на"; break;
case "la tariffa":  				$messaggio = "тариф"; break;
case "indietro":  				$messaggio = "назад"; break;
case "avanti":  				$messaggio = "вперед"; break;
case "del":  					$messaggio = ""; break;
case "arrotondato a":  				$messaggio = "округлено до"; break;
case "Errore nei valori inseriti":  		$messaggio = "Ошибка во добавленных значениях"; break;
case "Assegnare automaticamente con le tariffe selezionate":	$messaggio = "Присвоить автоматически выбранные тарифы"; break;
case "Tariffe":  				$messaggio = "Тарифы"; break;
case "Il costo aggiuntivo":  			$messaggio = "Дополнительные расходы"; break;
case "OK":  					$messaggio = "OK"; break;
case "Le settimane a cui applicare il costo":	$messaggio = "Недели для применения стоимости к"; break;
case "I giorni a cui applicare il costo":	$messaggio = "Дни для применения стоимость"; break;
case "uno":  					$messaggio = "один"; break;
case "NO":  					$messaggio = "НЕТ"; break;
case "SI":  					$messaggio = "ДА"; break;
case "Tariffe incompatibili con il costo":  	$messaggio = "Тарифы, которые несовместимы со стоимостью"; break;
case "Tariffe incompatibili":  			$messaggio = "Несовместимые тарифы"; break;
case "dalla":  					$messaggio = "от"; break;
case "I prezzi della tariffa selezionata sono stati importati":	$messaggio = "Прайсы выбранного тарифы были импортированы"; break;
case "importa":  				$messaggio = "импорт"; break;
case "se selezionato mantenere anche":  	$messaggio = "если выбрано сохранить также"; break;
case "Quando possibile assegna automaticamente se mancano":	$messaggio = "Когда возможно присвоить автоматически, если"; break;
case "meno di":  				$messaggio = "менее чем"; break;
case "più di":  				$messaggio = "более чем"; break;
case "giorni dalla data iniziale della prenotazione quando viene inserita":	$messaggio = "дни остаются от даты начала брони, когда она добавлена"; break;
case "Quando possibile assegna automaticamente se si inseriscono":	$messaggio = "Когда возможно присвоить автоматически, если"; break;
case "o più prenotazioni contemporaneamente":	$messaggio = "или больше броней  вставлено одновременно"; break;
case "Modifica il costo":  			$messaggio = "Изменить стоимость"; break;
case "Inserisci un nuovo costo aggiuntivo chiamato":	$messaggio = "Добавить новый дополнительный расход названный"; break;
case "importando le caratteristiche da":	$messaggio = "импортируя настройки из"; break;
case "Sempre in periodi permessi":  		$messaggio = "Всегда в разрешенные периоды"; break;
case "Prezzo dell'intera settimana":  				$messaggio = "Цена всей недели"; break;
case "è":  					$messaggio = "is"; break;
case "il":  					$messaggio = "the"; break;
case "sono":  					$messaggio = "are"; break;
case "Sulla":  					$messaggio = "On"; break;
case "p":  					$messaggio = "p"; break;
case "Se":  					$messaggio = "If"; break;
case "Se si inseriscono":  			$messaggio = "If"; break;
case "a":  					$messaggio = "to"; break;
case "Crea Prezzi":  				$messaggio = "Insert Prices"; break;
case "La caparra normale per":  		$messaggio = "The normal deposit for"; break;
case "già esiste, vai alla pagina di visualizzazione periodi e tariffe per cancellarlo":	$messaggio = "already exists, go to the page with the periods and the rates to delete it"; break;
case "già esiste, usa il tasto \"modifica i prezzi già inseriti\" per cambiarlo o non metterlo per inserire prezzi per nuovi periodi":	$messaggio = "already exists, use the button \"modify already inserted prices\" to change it, or don't insert it to insert prices in new periods"; break;
case "già esiste, ne devi usare un'altro":  	$messaggio = "already exists, you must use another one"; break;
case "esiste già, usa il tasto \"modifica i prezzi già inseriti\" per cambiarlo":	$messaggio = "already exists, use the button \"modify already inserted prices\" to change it"; break;
case "Inserzione per giorni":			$messaggio = "Insertion on daily basis"; break;
case "Inserzione per settimane":  		$messaggio = "Insertion on weekly basis"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>finale</b>":	$messaggio = "Choose the rates to which apply automatically the <b>single</b> extra cost"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>settimanale</b>":	$messaggio = "Choose the rates to which apply automatically the <b>weekly</b> extra cost"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>giornaliero</b>":	$messaggio = "Choose the rates to which apply automatically the <b>daily</b> extra cost"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>percentuale</b>":	$messaggio = "Choose the rates to which apply automatically the <b>percentage</b> extra cost"; break;
case "Costo aggiuntivo già esistente":  	$messaggio = "Extra cost already inserted"; break;
case "i prezzi della":  			$messaggio = "the prices to"; break;
case "aggiungendo":  				$messaggio = "adding"; break;
case "Prezzi dei giorni":  			$messaggio = "Prices of days"; break;
case "tra":  					$messaggio = "between"; break;
case "Beni dell'inventario da eliminare quando si inserisce il costo":	$messaggio = "Inventory items to delete when the cost is inserted"; break;
case "Nessuno":  				$messaggio = "No one"; break;
case "Beni selezionati":  			$messaggio = "Selected items"; break;
case "Aggiungi un bene":  			$messaggio = "Add an item"; break;
case "Elimina un bene":  			$messaggio = "Delete an item"; break;
case "elimina i beni dall'inventario del magazzino":	$messaggio = "Delete items from inventory of stockroom"; break;
case "Beni dell'inventario da eliminare":  	$messaggio = "Inventory items to delete"; break;
case "Mostrare raggruppato con costi simili della stessa categoria in inserimento":	$messaggio = "Display grouped with similar costs from same category in insertion"; break;
case "Il tipo di applicazione della":  		$messaggio = "The enforcement type of"; break;
case "per persona":  				$messaggio = "per person"; break;
case "per settimana":  				$messaggio = "per week"; break;
case "per giorno":  				$messaggio = "per day"; break;
case "La caparra è errata":  			$messaggio = "The deposit is wrong"; break;
case "Commissioni":  				$messaggio = "Commissions"; break;
case "Le commissioni normali su":  		$messaggio = "The normal commissions on"; break;
case "Inserisci o modifica le commissioni":  	$messaggio = "Insert or modify commissions"; break;
case "Tasse":  					$messaggio = "Taxes"; break;
case "Tasse applicate su":  			$messaggio = "Taxes applied on"; break;
case "della tariffa":  				$messaggio = "of the rate"; break;
case "Inserisci o modifica le tasse":  		$messaggio = "Insert or modify taxes"; break;
case "Le commissioni sono state modificate":  	$messaggio = "Commissions have been modified"; break;
case "Le commissioni sono errate":  		$messaggio = "Commissions are wrong"; break;
case "Le tasse sono state modificate":  	$messaggio = "Taxes have been modified"; break;
case "Le tasse sono errate":  			$messaggio = "Taxes are wrong"; break;
case "tutti i prezzi delle tariffe si intendono con tasse già incluse":	$messaggio = "All rate prices are considered as already including taxes"; break;
case "Inserisci o modifica le commissioni normali":  	$messaggio = "Insert or modify the normal commissions"; break;
case "Inserisci o modifica le commissioni in questo periodo":  	$messaggio = "Insert or modify commissions in this period"; break;
case "al giorno":  				$messaggio = "per day"; break;
case "alla settimana":  			$messaggio = "per week"; break;
case "il valore del costo si intente con tasse già incluse":	$messaggio = "the cost value is considered as already including taxes"; break;
case "Categoria":  				$messaggio = "Category"; break;
case "il prezzo della tariffa per i primi":  	$messaggio = "the rate price for the first"; break;
case "il prezzo della tariffa per le prime":  	$messaggio = "the rate price for the first"; break;
case "della":  					$messaggio = "of the"; break;
case "tariffa + sconto":  			$messaggio = "rate + discount"; break;
case "tariffa + sconto + costi agg.":  		$messaggio = "rate + discount + extra costs"; break;
case "della tar.":  				$messaggio = "of rate"; break;
case "di t.+s.":  				$messaggio = "of r.+d."; break;
case "di t.+s.+c.a.":  				$messaggio = "of r.+d.+e.c."; break;
case "Nome della":  				$messaggio = "Name of"; break;
case "Cambia":  				$messaggio = "Change"; break;
case "prezzo per settimana":  			$messaggio = "price per week"; break;
case "prezzo per giorno":  			$messaggio = "price per day"; break;
case "prezzo per persona per settimana":  	$messaggio = "price per person per week"; break;
case "prezzo per persona per giorno":  		$messaggio = "price per person per day"; break;
case "parte fissa della tariffa":  		$messaggio = "fixed part of the rate"; break;
case "parte per una persona della tariffa":  	$messaggio = "one person part of the rate"; break;
case "Numero massimo":  			$messaggio = "Maximum number"; break;
case "0 se illimitato":  			$messaggio = "0 for unlimited"; break;
case "meno":  					$messaggio = "minus"; break;
case "il costo viene moltiplicato per zero se la somma è negativa":	$messaggio = "the cost will be multiplied by zero if the sum is negative"; break;
case "Combina con altri costi":			$messaggio = "Combine with other costs"; break;
case "i costi combinabili vengono mostrati tutti assieme con il nome della categoria ed ognuno è inserito se possibile":	$messaggio = "combined costs are shown all together with category name and each one is inserted when possible"; break;
case "opzionale":  				$messaggio = "optional"; break;
case "Costi combinati":  			$messaggio = "Combined costs"; break;
case "Inserimento rapido di un nuovo costo aggiuntivo per":	$messaggio = "Fast insertion of a new extra cost for"; break;
case "permanenza minima":  			$messaggio = "minimum stay"; break;
case "numero di neonati":  			$messaggio = "number of infants"; break;
case "letto aggiuntivo":  			$messaggio = "extra bed"; break;
case "offerta speciale":  			$messaggio = "special offer"; break;
case "inserisci":  				$messaggio = "insert"; break;
case "Inserisci il costo aggiuntivo":  		$messaggio = "Insert the extra cost"; break;
case "Numero minimo di giorni":  		$messaggio = "Minimum number of days"; break;
case "Applicato alle tariffe":  		$messaggio = "Applied to rates"; break;
case "Periodi in cui viene applicato il costo":	$messaggio = "Periods in which the cost is applied"; break;
case "Valore per ogni neonato":  		$messaggio = "Value for each infant"; break;
case "del prezzo di una persona":  		$messaggio = "of the price for one person"; break;
case "solo per tariffe con prezzi a persona":  	$messaggio = "only for rates with per person prices"; break;
case "con questo costo il numero di neonati non è incluso nel numero di persone":	$messaggio = "with this cost the number of infants is not included in the number of people"; break;
case "Valore del letto aggiuntivo":  		$messaggio = "Value of the extra bed"; break;
case "Valore dello sconto":  			$messaggio = "Discount value"; break;
case "del prezzo totale":  			$messaggio = "of total price"; break;
case "Se la prenotazione ha una durata di":	$messaggio = "If the reservation length is"; break;
case "o più giorni":  				$messaggio = "days or more"; break;
case "Importa ora":  				$messaggio = "Import now"; break;
case "Importa sempre":  			$messaggio = "Always import"; break;
case "cancella":  				$messaggio = "delete"; break;
case "L'importatazione dei prezzi è stata cancellata":	$messaggio = "The prices import has been deleted"; break;
case "al prezzo fisso":  			$messaggio = "to fixed price"; break;
case "al prezzo per persona":  			$messaggio = "to per person price"; break;
case "ad entrambi i prezzi":  			$messaggio = "to both prices"; break;
case "La tariffa":  				$messaggio = "The rate"; break;
case "esporta i prezzi ad altre tariffe, non può importare i prezzi in modo permanente":	$messaggio = "exports its prices to other rates, it can't import prices permanently"; break;
case "tutte le tariffe":  			$messaggio = "all rates"; break;
case "considerare l'intero costo come tasse":  	$messaggio = "consider the entire cost as taxes"; break;
case "Escludere questo costo dal totale per altri costi percentuali":	$messaggio = "Exclude this cost from the total for other percentage costs"; break;
case "in tutti i periodi in modo predefinito":	$messaggio = "in all periods by default"; break;
case "importa i prezzi da altre tariffe, non può esportare i prezzi":	$messaggio = "imports its prices from other rates, so can't export its prices"; break;
case "importa già i prezzi da altre tariffe in questi periodi, non può importare altri prezzi":	$messaggio = "already imports its prices from other rates in these periods, can't import other prices"; break;
case "modifica":  				$messaggio = "modify"; break;
case "In modo predefinito importa":  		$messaggio = "By default import"; break;
case "i prezzi di alcuni periodi <em>non sono stati inseriti</em> perchè importati da altre tariffe":	$messaggio = "the prices of some periods <em>have not been inserted</em> because they are imported from other rates"; break;
case "limite non considerato per le persone aggiuntive nelle interconnessioni":	$messaggio = "limit not considered for additional people in interconnections"; break;
case "Seleziona adesso questo costo anche per tutti gli utenti che non hanno privilegi per usare tutti i costi":	$messaggio = "Select now this cost also for all the users that don't have privileges to use all the costs"; break;
case "Aggiungi adesso questo costo a tutte le pagine create per il sito web":	$messaggio = "Add now this cost to all existing website pages"; break;
case "Se si moltiplica per il numero di persone":	$messaggio = "When multiplying by the number of people"; break;
case "escludi":  				$messaggio = "exclude"; break;
case "includi solo":  				$messaggio = "include only"; break;
case "questi tipi":  				$messaggio = "these types"; break;
case "Mostrare come tipo di persona":  		$messaggio = "Display as person type"; break;
case "Applicare la percentuale del tipo di persona al prezzo del costo":	$messaggio = "Apply the percentage of the person type to the price of the cost"; break;
case "Neonati (0-23 mesi)":  			$messaggio = "Infants (0-23 months)"; break;
case "tariffe con":  				$messaggio = "rates with"; break;
case "per persona nullo":  			$messaggio = "per person zero"; break;
case "fisso nullo":  				$messaggio = "fixed zero"; break;
case "da per persona":  			$messaggio = "from per person"; break;
case "più fisso":  				$messaggio = "from fixed"; break;
case "dal fisso":  				$messaggio = "plus fixed"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>